@@ -15,6 +15,7 @@ if not find_spec("class_registry"):
 
 from .cog import SentinelCog
 from .db import AbstractPartial, Change, Moderation, PartialChannel, PartialGuild, PartialUser
+from .exceptions import HandlerError, LoggedHandlerError
 from .type import ModerationType, moderation_type_registry
 
 __all__ = [
@@ -27,6 +28,8 @@ __all__ = [
     "PartialUser",
     "ModerationType",
     "moderation_type_registry",
+    "HandlerError",
+    "LoggedHandlerError",
 ]
 
 warn("Tidegear Sentinel is still a heavy work-in-progress, and it has been imported!")
