@@ -32,8 +32,9 @@ from typing_extensions import override
 from tidegear import Cog
 from tidegear.exceptions import ConfigurationError, ContextError
 from tidegear.sentinel.db import Change, Moderation, PartialChannel, PartialGuild, PartialUser
+from tidegear.sentinel.exceptions import HandlerError, LoggedHandlerError
 from tidegear.sentinel.type import ModerationType, moderation_type_registry
-from tidegear.utils import TimestampStyle, class_overrides_method, format_datetime, get_asset_as_file, send_error, set_env, title, truncate_string
+from tidegear.utils import TimestampStyle, class_overrides_attribute, format_datetime, get_asset_as_file, send_error, set_env, title, truncate_string
 
 
 class SentinelCog(Cog):
@@ -215,7 +216,7 @@ class SentinelCog(Cog):
     @property
     def adds_moderation_types(self) -> bool:
         """Check whether or not a cog class overrides the [`moderation_types`][tidegear.sentinel.SentinelCog.moderation_types] method."""
-        return class_overrides_method(child=type(self), parent=SentinelCog, method_name="moderation_types")
+        return class_overrides_attribute(child=type(self), parent=SentinelCog, attribute="moderation_types")
 
     def get_sentinel_cogs(self) -> Mapping[str, "SentinelCog"]:
         """Get a mapping of all cogs that are currently loaded that are subclasses of SentinelCog.
@@ -311,7 +312,7 @@ class SentinelCog(Cog):
         ctx: commands.Context | Interaction,
         target: Member | User | abc.GuildChannel | Thread,
         moderation_type: ModerationType | str,
-        silent: bool = False,
+        silent: bool = MISSING,
         **kwargs: Any,
     ) -> None | Moderation:
         """Moderate a user.
@@ -350,13 +351,33 @@ class SentinelCog(Cog):
             await send_error(ctx, content=str(err), ephemeral=True)
             return None
 
-        moderation = await moderation_type.handler(target=target)(ctx=ctx, target=target, **kwargs)
+        try:
+            moderation_handler = moderation_type.handler(target=target)
+        except TypeError as err:
+            await send_error(ctx, content=str(err), ephemeral=True)
+            return None
 
+        try:
+            moderation = await moderation_handler(ctx=ctx, target=target, **kwargs)
+        except HandlerError as err:
+            await send_error(ctx, content=str(err), ephemeral=err.send_error_kwargs.pop("ephemeral", True), **err.send_error_kwargs)
+            return None
+        except LoggedHandlerError as err:
+            await send_error(ctx, content=str(err), ephemeral=err.send_error_kwargs.pop("ephemeral", True), **err.send_error_kwargs)
+            self._sentinel_logger.exception("Encountered exception within moderation handler %s", moderation_handler)
+            return None
+        except Exception:
+            await send_error(ctx, content="Internal error encountered, report this to the bot owner!", ephemeral=True)
+            self._sentinel_logger.exception("Encountered exception within moderation handler %s", moderation_handler)
+            return None
+
+        if silent == MISSING:
+            silent = await self.get_type_config_with_fallback(ctx.guild, moderation_type, "dm_users")
         if not silent:
             try:
                 await self.contact_target(moderation)
             except (ConfigurationError, TypeError) as err:
-                self.logger.warning("Unable to contact target '%s'!", target.id, exc_info=err)
+                self._sentinel_logger.warning("Unable to contact target '%s'!", target.id, exc_info=err)
             except Forbidden:
                 pass
 
